package com.citra.pivot.demo;

import java.awt.Color;
import java.awt.Component;
import java.awt.Font;

import javax.swing.tree.TreePath;

import com.citra.pivot.PivotColumnAdapter;
import com.citra.pivot.PivotConstants;
import com.citra.pivot.PivotRowAdapter;
import com.citra.pivot.PivotStyle;
import com.citra.pivot.PivotTable;
import com.citra.pivot.olap.DefaultOlapStyleModel;
import com.citra.pivot.olap.data.OlapCell;
/**
 *
 */
public class OlapDemoStyleModel extends DefaultOlapStyleModel {
	protected Font summary;
	protected Font normal;

	protected boolean applyStyle = true;
/**
 *
 */
public OlapDemoStyleModel() {
	summary = new Font("Tahoma", Font.ITALIC | Font.BOLD, 11);
	normal = new Font("Arial", Font.BOLD, 11);
}
/**
 *
 */
public void applyColumnHeaderStyle(Component c, PivotTable table, PivotColumnAdapter adapter, TreePath path, int level, int column) {
	if (applyStyle) {
		int type = adapter.getPivotType(path);
		if (type == PivotConstants.SUBTOTAL_TYPE) {
			defaultColumnHeaderStyle.setForeground(Color.red);
			defaultColumnHeaderStyle.setBackground(Color.cyan);
			defaultColumnHeaderStyle.setFont(summary);
		}
		else if (type == PivotConstants.GRAND_TOTAL_TYPE) {
			defaultColumnHeaderStyle.setForeground(Color.white);
			defaultColumnHeaderStyle.setBackground(Color.magenta);
			defaultColumnHeaderStyle.setFont(summary);
		}
		else {
			defaultColumnHeaderStyle.setForeground(c.getForeground());
			defaultColumnHeaderStyle.setBackground(c.getBackground());
			defaultColumnHeaderStyle.setFont(normal);
		}	
	}
	super.applyColumnHeaderStyle(c, table, adapter, path, level, column);
}
/**
 *
 */
public void applyDataStyle(Component c, PivotTable table, PivotRowAdapter[] rowAdapters, TreePath[] rowPaths, PivotColumnAdapter[] columnAdapters, TreePath[] columnPaths, int row, int column, Object value) {
	if (applyStyle) {
		OlapCell cell = (OlapCell) value;
		if (cell != null) {
			Object cellValue = cell.getValue();
			defaultDataStyle.setBackground(Color.white);
			defaultDataStyle.setForeground(Color.black);
			defaultDataStyle.setFontStyle(Font.PLAIN);
			if ((cell.getMeasure().getName().equals("Net Sales") || cell.getMeasure().getName().equals("Max Sales")) && cellValue instanceof Number) {
				Number n = (Number) cell.getValue();
				double dvalue = n.doubleValue();
				if (dvalue < 1000) {
					defaultDataStyle.setBackground(Color.red);
				}
				else if (dvalue > 10000) {
					defaultDataStyle.setBackground(Color.green);
					defaultDataStyle.setFontStyle(Font.ITALIC);
				}
				else defaultDataStyle.setBackground(c.getBackground());
			}
			else {
				defaultDataStyle.setBackground(c.getBackground());
			}
			boolean rowGrand = false;
			if (rowAdapters.length > 0) {
				int type = rowAdapters[0].getPivotType(rowPaths[0]);
				if (type == PivotConstants.GRAND_TOTAL_TYPE) {
					rowGrand = true;
				}
			}
			boolean columnGrand = false;
			if (columnAdapters.length > 0) {
				int type = columnAdapters[0].getPivotType(columnPaths[0]);
				if (type == PivotConstants.GRAND_TOTAL_TYPE) {
					columnGrand = true;
				}
			}
			if (columnGrand || rowGrand) {
				defaultDataStyle.setBackground(Color.magenta);
				defaultDataStyle.setForeground(Color.white);
				defaultDataStyle.setFontStyle(Font.BOLD);
			}
		}
	}
	super.applyDataStyle(c, table, rowAdapters, rowPaths, columnAdapters, columnPaths, row, column, value);
}
/**
 *
 */
public void applyRowHeaderStyle(Component c, PivotTable table, PivotRowAdapter adapter, TreePath path, int row, int column) {
	if (applyStyle) {
		int type = adapter.getPivotType(path);
		if (type == PivotConstants.SUBTOTAL_TYPE) {
			defaultRowHeaderStyle.setForeground(Color.red);
			defaultRowHeaderStyle.setBackground(Color.cyan);
			defaultRowHeaderStyle.setFont(summary);
		}
		else if (type == PivotConstants.GRAND_TOTAL_TYPE) {
			defaultRowHeaderStyle.setForeground(Color.white);
			defaultRowHeaderStyle.setBackground(Color.magenta);
			defaultRowHeaderStyle.setFont(summary);
		}
		else {
			defaultRowHeaderStyle.setForeground(c.getForeground());
			defaultRowHeaderStyle.setBackground(c.getBackground());
			defaultRowHeaderStyle.setFont(normal);
		}
	}
	super.applyRowHeaderStyle(c, table, adapter, path, row, column);
}
/**
 *
 */
public boolean getApplyStyle() {
	return applyStyle;
}
/**
 *
 */
public void setApplyStyle(boolean apply) {
	if (!apply) {
		//revert to defaults
		defaultColumnHeaderStyle = new PivotStyle();
		defaultRowHeaderStyle = new PivotStyle();
		defaultDataStyle = new PivotStyle();
		defaultColumnHeaderStyle.setFontStyle(Font.BOLD);
		defaultRowHeaderStyle.setFontStyle(Font.BOLD);
		defaultDataStyle.setForeground(Color.black);
	}
	this.applyStyle = apply;
}
}
